@@ -1,6 +1,6 @@
 package App::WIoZ::Word;
 BEGIN {
-  $App::WIoZ::Word::VERSION = '0.002';
+  $App::WIoZ::Word::VERSION = '0.003';
 }
 use Moose;
 #use feature 'say';
@@ -51,8 +51,8 @@ has 'show' => (
 );
 
 has 'angle' => (
-    is => 'ro', isa => 'Num',
-    default => sub {return rand(1.0) > 0.85 ? -1 * 2 * atan2(1, 1) : '0.0';}
+    is => 'ro', isa => 'Str',
+    default => sub {return rand(1.0) > 0.85 ? -1 * 2 * atan2(1, 1) : 0;}
 );
 
 sub update_c {
